@@ -77,6 +77,7 @@ class RedisCustomer(object):
         redis队列消费程序
         :param queue_name: 队列名称
         :param consuming_function: 队列消息取出来后执行的方法
+        :param process_num: 启动进程数量
         :param threads_num: 启动多少个线程(档customer_type=gevent时为协程数量)
         :param max_retry_times: 错误重试次数
         :param func_timeout: 函数超时时间(秒)
@@ -327,13 +328,16 @@ class RedisPublish(object):
             if kwargs:
                 dict_msg = sort_dict(kwargs)
             if args:
-                param = dict() if dict_msg is None else dict_msg
-                try:
-                    for arg_index in range(0, len(args)):
-                        param[keys[arg_index]] = args[arg_index]
-                    dict_msg = param
-                except Exception:
-                    raise Exception('发布任务和消费函数参数不一致,请仔细核对')
+                if len(args) == 1 and type(args[0]) == dict:
+                    dict_msg = args[0]
+                else:
+                    param = dict() if dict_msg is None else dict_msg
+                    try:
+                        for arg_index in range(0, len(args)):
+                            param[keys[arg_index]] = args[arg_index]
+                        dict_msg = param
+                    except Exception:
+                        raise Exception('发布任务和消费函数参数不一致,请仔细核对')
             dict_msg = sort_dict(dict_msg)
         else:
             if kwargs:
